@@ -9,8 +9,7 @@ import srsly
 from genbase._version import __version__
 from genbase.data import import_data, rename_labels, train_test_split
 from genbase.decorator import add_callargs
-from genbase.internationalization import (LOCALE_MAP, get_locale, set_locale,
-                                          translate_list, translate_string)
+from genbase.internationalization import LOCALE_MAP, get_locale, set_locale, translate_list, translate_string
 from genbase.mixin import CaseMixin, SeedMixin
 from genbase.model import import_model
 from genbase.ui import Render, is_interactive
@@ -193,6 +192,10 @@ class MetaInfo(Configurable):
     def renderargs(self):
         return self._renderargs if self._renderargs is not None else {}
 
+    @property
+    def html(self):
+        return self._renderer(self.to_config()).as_html(**self.renderargs)
+
     def to_config(self):
         if hasattr(self, 'content'):
             _content = self.content() if callable(self.content) else self.content
@@ -203,4 +206,4 @@ class MetaInfo(Configurable):
         return {'META': self.meta, 'CONTENT': content}
 
     def _repr_html_(self) -> str:
-        return self._renderer(self.to_config()).as_html(**self.renderargs) if is_interactive() else repr(self)
+        return self.html if is_interactive() else repr(self)
